import { NativeModules, Platform } from 'react-native';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import Feather from 'react-native-vector-icons/Feather';
import EvilIcons from 'react-native-vector-icons/EvilIcons';

const { RNDropdownNotification } = NativeModules;

class NotificationBanner {
  static defaultProps = {
    type: 0,
    title: '',
    titleSize: 0,
    titleColor: '',
    subTitle: '',
    subTitleSize: 0,
    subTitleColor: '',
    duration: 0,
    enableProgress: false,
    tintColor: '',
    withIcon: true,
    dismissable: true,
  };

  static Types = {
    Normal: 0,
    Info: 1,
    Success: 2,
    Warn: 3,
    Error: 4,
  };

  static Styles = {
    success: {
      tintColor: '#4b994f',
      icon: <Feather name="check-circle" size={22} color="#FFFFFF" family="Feather" />,
    },
    warn: {
      tintColor: '#feb119',
      icon: <Feather name="minus-circle" size={22} color="#FFFFFF" family="Feather" />,
    },
    error: {
      tintColor: '#d81919',
      icon: <Feather name="x-circle" size={22} color="#FFFFFF" family="Foundation" />,
    },
    info: {
      tintColor: '#5162bc',
      icon: <Feather name="info" size={22} color="#FFFFFF" family="MaterialIcons" />,
    },
    normal: {
      tintColor: '#484d51',
    },
  };

  static Show(props) {
    let values = {
      ...NotificationBanner.defaultProps,
      ...props,
    };

    if (!props.withIcon) {
      values.icon = undefined;
    }

    let _onClick = () => {
      props.onClick && props.onClick();
    };
    let _onHide = () => {
      props.onHide && props.onHide();
    };

    RNDropdownNotification.Show(values, _onClick, _onHide);
  }

  static Success(props) {
    let values = {
      ...NotificationBanner.defaultProps,
      tintColor: NotificationBanner.Styles.success.tintColor,
      icon: NotificationBanner.Styles.success.icon,
      ...props,
      type: NotificationBanner.Types.Success,
    };

    NotificationBanner.Show(values);
  }

  static Error(props) {
    let values = {
      ...NotificationBanner.defaultProps,
      tintColor: NotificationBanner.Styles.error.tintColor,
      icon: NotificationBanner.Styles.error.icon,
      ...props,
      type: NotificationBanner.Types.Error,
    };

    NotificationBanner.Show(values);
  }

  static Info(props) {
    let values = {
      ...NotificationBanner.defaultProps,
      tintColor: NotificationBanner.Styles.info.tintColor,
      icon: NotificationBanner.Styles.info.icon,
      ...props,
      type: NotificationBanner.Types.Info,
    };

    NotificationBanner.Show(values);
  }

  static Warn(props) {
    let values = {
      ...NotificationBanner.defaultProps,
      tintColor: NotificationBanner.Styles.warn.tintColor,
      icon: NotificationBanner.Styles.warn.icon,
      ...props,
      type: NotificationBanner.Types.Warn,
    };

    NotificationBanner.Show(values);
  }

  static Normal(props) {
    let values = {
      ...NotificationBanner.defaultProps,
      tintColor: NotificationBanner.normalStyle.tintColor,
      ...props,
      type: NotificationBanner.Types.Normal,
    };

    NotificationBanner.Show(values);
  }

  static Dismiss() {
    RNDropdownNotification.Dismiss();
  }
}

export { NotificationBanner as RNDropdownNotification };
